//#define XERR
#include "mammo.ih"

void Mammo::insertBeta(ostream &out, size_t begin, size_t end) const
{
    out << ' ';

    Globals::setPrecision(out, 2);

    for (; begin != end; ++begin)
        out << begin << ": " << d_beta[begin] << ",  ";

}
